FloatPool

Struct FloatPool 

pub struct FloatPool { /* private fields */ }
Structure for interning similar floats based on approximate equality.

Examples

use approx_collections::FloatPool;

let mut pool = FloatPool::default();

let very_small_delta = 0.0000000001;

assert_eq!(pool.intern(4.0), 4.0);
assert_eq!(pool.intern(4.0 + very_small_delta), 4.0);
assert_eq!(pool.intern(4.0 - very_small_delta), 4.0);

assert_eq!(pool.intern(3.0 - very_small_delta), 3.0 - very_small_delta);
assert_eq!(pool.intern(3.0), 3.0 - very_small_delta);

Implementations

Source

impl FloatPool

pub fn new(prec: Precision) -> Self

Constructs a new float interner with the given precision.

pub fn prec(&self) -> Precision

Returns the precision level used by the interner.

pub fn intern<V: ApproxInternable>(&mut self, value: V) -> V

Replaces all floats in value with interned ones that are approximately equal, returning a mutated copy of value.

If any floats in value are have not already been interned, they are added to the pool and unmodified.

pub fn intern_in_place<V: ApproxInternable>(&mut self, value: &mut V)

Replaces all floats in value with interned ones that are approximately equal.

If any floats in value are have not already been interned, they are added to the pool and unmodified.

pub fn try_intern<V: ApproxInternable>(&self, value: V) -> Option<V>

Replaces all floats in value with interned ones that are approximately equal, returning a mutated copy of value. Returns None if any floats in value are not already in the pool.

pub fn bucket_count(&self) -> usize

Returns the number of occupied buckets in the pool.

pub fn iter(&self) -> Iter<'_>

Iterates over all floats in the pool, in an undefined order.